#
# spec file for package python-recordclass
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-recordclass
Version:        0.22.1
Release:        2.1
Summary:        Library implementing a mutable variant of namedtuple
License:        MIT
URL:            https://github.com/intellimath/recordclass
Source:         https://files.pythonhosted.org/packages/source/r/recordclass/recordclass-%{version}.tar.gz
# PATCH-FIX-UPSTREAM Based on gh#intellimath/recordclass#338044cbf771e5665a744d3b36b5d7edd126d16a
Patch0:         do-not-use-pytuple-get-size.patch
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# SECTION Test requirements
BuildRequires:  %{python_module psutil}
BuildRequires:  %{python_module pyperf}
# /SECTION
%python_subpackages

%description
Mutable variant of namedtuple -- recordclass, which support assignments, and
other memory saving variants.

%prep
%autosetup -p1 -n recordclass-%{version}

%build
export CFLAGS="%{optflags}"
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
# Crashes when run using pytest
%python_expand PYTHONPATH=%{buildroot}%{$python_sitearch} python%{$python_version} test_all.py

%files %{python_files}
%doc README.md
%license LICENSE.txt
%{python_sitearch}/recordclass/
%{python_sitearch}/recordclass-%{version}.dist-info

%changelog
* Fri Apr  4 2025 Steve Kowalik <steven.kowalik@suse.com>
- Add patch do-not-use-pytuple-get-size.patch:
  * Use Py_SIZE rather than PyTuple_GET_SIZE to avoid assertion failures.
* Mon Aug  5 2024 Dirk Müller <dmueller@suse.com>
- update to 0.22.1:
  * Add `pyproject.toml`.
- update to 0.22.0.3:
  * Rename examples	est_*.py files since they are detected by
    pytest as a tests.
  * Fix segfault with litelist after 0.22.0.2.
* Tue Jul  2 2024 Dirk Müller <dmueller@suse.com>
- update to 0.22.0.2:
  * Fix regression with `as_dataclass`.
- update to 0.22:
  * `Recordclass 0.22` started support of `python 3.13`.
  * Add a base class `datastruct` for subclasses that should
    behave more like simple datastructures.
  * Fix bug with `__match_args__` (#6).
* Fri Dec 29 2023 Dirk Müller <dmueller@suse.com>
- update to 0.21.1:
  * Allow to specify __match_args__.
  * Add @as_record adapter for def-style decalarations of
    dataclasses that are considered as just a struct.
  * The option fast_new will be removed in 0.22. It will be
    always as fast_new=True by creation.
  * Fix issues with `_PyUnicodeWriter`  for python 3.13.
* Wed Nov  9 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 0.18.0.1
  * Exclude test_dataobject_match.py (for testing match statement) for python < 3.10.
- Update to 0.18
  * Python 3.11 support.
  * Adapt data object to take benefit from bytecode specialization in 3.11.
  * Fix issue for argument with default value in __new__, which havn't __repr__ that can be interpreted as valid python expression for creation of the default value.
  * Add support for typing.ClassVar.
  * Add Py_TPFLAGS_SEQUENCE and Py_TPFLAGS_MAPPING.
  * Add __match_args__ to support match protocol for dataobject-based subclasses.
* Fri Oct  7 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- 0.17.5
  Make to compile, to build and to test successfully for python 3.11.
* Sun Jul 31 2022 Atri Bhattacharya <badshah400@gmail.com>
- Initial package.
